@@ -7,6 +7,6 @@ test_that("function works", {
   expect_equal(sound_speed(0),1449.06623)
 })
 
-test_that("function does not works", {
+test_that("function does not work", {
   expect_error(sound_speed(8, "1000", 34), "non-numeric argument to binary operator")
-})
\ No newline at end of file
+})
